Repository: commons-dbcp
Updated Branches:
  refs/heads/master 0b10d14e4 -> beb266a7c


fix typo in private ivar name.

Project: http://git-wip-us.apache.org/repos/asf/commons-dbcp/repo
Commit: http://git-wip-us.apache.org/repos/asf/commons-dbcp/commit/beb266a7
Tree: http://git-wip-us.apache.org/repos/asf/commons-dbcp/tree/beb266a7
Diff: http://git-wip-us.apache.org/repos/asf/commons-dbcp/diff/beb266a7

Branch: refs/heads/master
Commit: beb266a7c1a91bea734bebcfcf0768790055e8ce
Parents: 0b10d14
Author: Gary Gregory <[email protected]>
Authored: Sun Jun 10 10:29:35 2018 -0600
Committer: Gary Gregory <[email protected]>
Committed: Sun Jun 10 10:29:35 2018 -0600

----------------------------------------------------------------------
 .../org/apache/commons/dbcp2/BasicDataSource.java     | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/commons-dbcp/blob/beb266a7/src/main/java/org/apache/commons/dbcp2/BasicDataSource.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/dbcp2/BasicDataSource.java 
b/src/main/java/org/apache/commons/dbcp2/BasicDataSource.java
index c5bbe1d..8a9186c 100644
--- a/src/main/java/org/apache/commons/dbcp2/BasicDataSource.java
+++ b/src/main/java/org/apache/commons/dbcp2/BasicDataSource.java
@@ -1065,21 +1065,21 @@ public class BasicDataSource implements DataSource, 
BasicDataSourceMXBean, MBean
     /**
      * The connection username to be passed to our JDBC driver to establish a 
connection.
      */
-    private String username;
+    private String userName;
 
     /**
      * Returns the JDBC connection {@link #username} property.
      *
-     * @return the {@link #username} passed to the JDBC driver to establish 
connections
+     * @return the {@link #userName} passed to the JDBC driver to establish 
connections
      */
     @Override
     public String getUsername() {
-        return this.username;
+        return this.userName;
     }
 
     /**
      * <p>
-     * Sets the {@link #username}.
+     * Sets the {@link #userName}.
      * </p>
      * <p>
      * Note: this method currently has no effect once the pool has been 
initialized. The pool is initialized the first
@@ -1091,7 +1091,7 @@ public class BasicDataSource implements DataSource, 
BasicDataSourceMXBean, MBean
      *            the new value for the JDBC connection username
      */
     public void setUsername(final String username) {
-        this.username = username;
+        this.userName = username;
     }
 
     /**
@@ -2195,7 +2195,7 @@ public class BasicDataSource implements DataSource, 
BasicDataSourceMXBean, MBean
         }
 
         // Set up the driver connection factory we will use
-        final String user = username;
+        final String user = userName;
         if (user != null) {
             connectionProperties.put("user", user);
         } else {
@@ -1065,21 +1065,21 @@ public class BasicDataSource implements DataSource, 
 
     /**
-     * Returns the JDBC connection {@link #username} property.
+     * Returns the JDBC connection {@link #userName} property.
      *

Reply via email to